package po

import (
	"fmt"
	"plugins/union_pay/internal/vo"
)

type OrderReq struct {
	ChNlId  string `validate:"required" json:"chnlId"`  // 渠道方代码-必填
	Qid     string `validate:"required" json:"qid"`     // 外部接入方定义的主键，保证唯一，即流水号，用于幂等校验
	OrderDt string `validate:"required" json:"orderDt"` // 请求日期-格式为yyyyMMdd
	// 银联营销平台用于上下文串联，取值可与QID相同，不强制校验是否唯一,-请求跟踪号
	TraceId string `validate:"required" json:"traceId"`
	// 优惠券ID-票券活动ID，由银联营销平台生成，31打头的16位数字 ，同优惠券状态通知接口的couponId
	DiscountId string `validate:"required" json:"discountId"`
	// 01：手机号维度；02：卡号维度；03：云闪付注册用户ID维度；05：外部用户ID维度；06：网络支付平台用户。
	// 07：证件号用户维度。票券的账户维度，同一个优惠券ID下的优惠券，其发放维度与核销维度一致，银行需确保支付交易中上送对应的要素。
	EntityTp string `validate:"required" json:"entityTp"`
	// 当entityTp为03时，cardNo、mobile、openId三选一必填；当entityTp为01时，mobile必填 该参数已配置加密规则：SM4
	Mobile      string `validate:"required" json:"mobile"`
	Cmd         string `validate:"required" json:"cmd"`
	AccessId    string `validate:"required" json:"accessId"`
	DiscountNum uint32 `validate:"required" json:"discountNum"`
}

type OrderResp struct {
	Code       vo.Code    `json:"code"`
	Msg        string     `json:"msg"`
	SubCode    vo.SubCode `json:"subCode"`
	SubMsg     string     `json:"subMsg"`
	DiscountId string     `json:"discountId"`
	Qid        string     `json:"qid"`
	CouponCd   string     `json:"couponCd"`
}

func (o *OrderResp) GetMsg() string {
	return fmt.Sprintf("Msg:[%s],SubMsg:[%s],自定处理msg:[%s]", o.Msg, o.SubMsg, o.SubCode.GetMsg())
}
